@@ -1,32 +1,27 @@
 import re
+import textwrap
 
 import yaml
 
-from pre_commit.clientlib import load_config
 from pre_commit.util import yaml_load
 
 
-def _indent(s: str) -> str:
-    lines = s.splitlines(True)
-    return ''.join(' ' * 4 + line if line.strip() else line for line in lines)
-
-
 def _is_header_line(line: str) -> bool:
     return line.startswith(('#', '---')) or not line.strip()
 
 
 def _migrate_map(contents: str) -> str:
-    # Find the first non-header line
-    lines = contents.splitlines(True)
-    i = 0
-    # Only loop on non empty configuration file
-    while i < len(lines) and _is_header_line(lines[i]):
-        i += 1
-
-    header = ''.join(lines[:i])
-    rest = ''.join(lines[i:])
-
     if isinstance(yaml_load(contents), list):
+        # Find the first non-header line
+        lines = contents.splitlines(True)
+        i = 0
+        # Only loop on non empty configuration file
+        while i < len(lines) and _is_header_line(lines[i]):
+            i += 1
+
+        header = ''.join(lines[:i])
+        rest = ''.join(lines[i:])
+
         # If they are using the "default" flow style of yaml, this operation
         # will yield a valid configuration
         try:
@@ -34,7 +29,7 @@ def _migrate_map(contents: str) -> str:
             yaml_load(trial_contents)
             contents = trial_contents
         except yaml.YAMLError:
-            contents = f'{header}repos:\n{_indent(rest)}'
+            contents = f'{header}repos:\n{textwrap.indent(rest, " " * 4)}'
 
     return contents
 
@@ -44,9 +39,6 @@ def _migrate_sha_to_rev(contents: str) -> str:
 
 
 def migrate_config(config_file: str, quiet: bool = False) -> int:
-    # ensure that the configuration is a valid pre-commit configuration
-    load_config(config_file)
-
     with open(config_file) as f:
         orig_contents = contents = f.read()
 
